@@ -2,4 +2,5 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-SYMBOLICATION_API = "https://symbols.mozilla.org/symbolicate/v5"
+# Default symbolication API URL
+SYMBOLICATION_API = "https://symbolication.services.mozilla.com/symbolicate/v5"
